@@ -15,7 +15,6 @@ import xmltodict
 import pysftp
 
 # Self import
-from logstack.decorators import log_to_remote
 from .models import LabportalenReport
 
 
@@ -116,7 +115,6 @@ class LabportalenService(BaseLabportalenService):
             raise Exception(f"Can not connect to the SFTP server, Exception: {e}")
         return sftp
     
-    @log_to_remote(settings.HTTP_LOGGER)
     def fetch_reports(self, requisition_id: Optional[str]=None) -> None:
         '''
         Fetches report from SFTP server
@@ -125,7 +123,11 @@ class LabportalenService(BaseLabportalenService):
         Returns:
             None
         '''
-        local_root_dir = os.path.join(self.base_dir, 'labportalen', 'sample_report')
+        local_root_dir = os.path.join(
+            self.base_dir,
+            'labportalen',
+            'sample_report'
+        )
         temp_path = local_root_dir + '/temp/'
         self._create_temp_dir_for_sftp_files(temp_path)
         sftp = self.authenticate_to_sftp()
@@ -136,15 +138,18 @@ class LabportalenService(BaseLabportalenService):
                 sftp.get(file_name, localpath=local_file_name)
             except Exception as e:
                 raise Exception(f"Couldn't get the file, {e}")
+            with open(local_file_name, 'rb') as fp:
+                data = fp.read()
+                parsed_data = xmltodict.parse(data)
+                requisition_id, test_results = self._save_parsed_xml_data(
+                    parsed_data,
+                    requisition_id
+                )
             if self.current_env_name == self.production_env_name:
                 try:
                     sftp.remove(file_name)
                 except Exception as e:
                     raise Exception(f"can not remove file, {e}")
-            with open(local_file_name, 'rb') as fp:
-                data = fp.read()
-                parsed_data = xmltodict.parse(data)
-                requisition_id, test_results = self._save_parsed_xml_data(parsed_data, requisition_id)
         sftp.close()
         print("SFTP Connection closed")
         self._delete_temp_dir_for_sftp_files(temp_path)
